@@ -236,11 +236,10 @@ dapls_ib_post_send (
 		 " post_snd: %s ep %p op %x flgs %x sgl %p,%d ln %d wr_id %Lx\n",
 		 PROVIDER_NAME, ep_ptr, wr.opcode, wr.send_flags, wr.sg_list,
 		 wr.num_sge, total_len, wr.wr_id);
-
 #ifdef _OPENIB_MCM_
 	if (ep_ptr->qp_handle->tp->scif_ep)
 		ret = dapli_mix_post_send(ep_ptr->qp_handle, total_len, &wr, &bad_wr);
-	else if (ep_ptr->qp_handle->ep_map == MIC_XSOCK_DEV)
+	else if (MXF_EP(ep_ptr->qp_handle))
 		ret = mcm_send_pi(ep_ptr->qp_handle, total_len, &wr, &bad_wr);
 	else
 		ret = ibv_post_send(ep_ptr->qp_handle->qp2, &wr, &bad_wr);
@@ -448,7 +447,7 @@ dapls_ib_post_ext_send (
 #ifdef _OPENIB_MCM_
 	if (ep_ptr->qp_handle->tp->scif_ep)
 		ret = dapli_mix_post_send(ep_ptr->qp_handle, total_len, &wr, &bad_wr);
-	else if (ep_ptr->qp_handle->ep_map == MIC_XSOCK_DEV)
+	else if (MXF_EP(ep_ptr->qp_handle))
 		ret = mcm_send_pi(ep_ptr->qp_handle, total_len, &wr, &bad_wr);
 	else
 		ret = ibv_post_send(ep_ptr->qp_handle->qp2, &wr, &bad_wr);
